kedro.framework.cli.utils — Kedro 0.17.6 documentation

# kedro.framework.cli.utils

Description

Utilities for use with click.

Functions

`command_with_verbosity`(group, *args, **kwargs) | Custom command decorator with verbose flag added.
`env_option`([func_]) | Add –env CLI option to a function.
`find_stylesheets`() | Fetch all stylesheets used in the official Kedro documentation
`forward_command`(group[, name, forward_help]) | A command that receives the rest of the command line as ‘args’.
`get_pkg_version`(reqs_path, package_name) | Get package version from requirements.txt.
`ipython_message`([all_kernels]) | Show a message saying how we have configured the IPython env.
`python_call`(module, arguments, **kwargs) | Run a subprocess command that invokes a Python module.
`split_string`(ctx, param, value) | Split string by comma.

Classes

`CommandCollection`(*groups) | Modified from the Click one to still run the source groups function.

Exceptions

`KedroCliError`(message) | Exceptions generated from the Kedro CLI.